@@ -4,14 +4,13 @@ use strict;
 use warnings;
 
 use Object::Simple::Util;
-use constant Util => 'Object::Simple::Util';
 use base 'Exporter';
 
 our @EXPORT_OK = qw/attr class_attr dual_attr/;
 
-sub attr        { _create_accessor(shift, 'attr',        @_) }
-sub class_attr  { _create_accessor(shift, 'class_attr',  @_) }
-sub dual_attr { _create_accessor(shift, 'dual_attr', @_) }
+sub attr       { _create_accessor(shift, 'attr',       @_) }
+sub class_attr { _create_accessor(shift, 'class_attr', @_) }
+sub dual_attr  { _create_accessor(shift, 'dual_attr',  @_)   }
 
 sub _create_accessor {
     my ($class, $type, $attrs, @options) = @_;
@@ -23,23 +22,19 @@ sub _create_accessor {
     $attrs = [$attrs] unless ref $attrs eq 'ARRAY';
     
     # Arrange options
-    my $options = @options > 1 ? {@options} : {build => $options[0]};
-    
-    # Upgrade
-    my $default = delete $options->{default};
-    $options->{build} = $default if $default;
+    my $options = @options > 1 ? {@options} : {default => $options[0]};
     
     foreach my $attr (@$attrs) {
         
         # Create accessor
         my $code = $type eq 'attr'
-                 ? Util->create_accessor($class, $attr, $options)
+                 ? Object::Simple::Util->create_accessor($class, $attr, $options)
                  
                  : $type eq 'class_attr'
-                 ? Util->create_class_accessor($class, $attr, $options)
+                 ? Object::Simple::Util->create_class_accessor($class, $attr, $options)
                  
                  : $type eq 'dual_attr'
-                 ? Util->create_dual_accessor($class, $attr, $options)
+                 ? Object::Simple::Util->create_dual_accessor($class, $attr, $options)
                  
                  : undef;
         
