@@ -1,10 +1,10 @@
 package B5;
-use Object::Simple;
+use Object::Simple::Old;
 
 sub m1 { die "" }
 
 sub m3 { die "" }
 sub m4 { $_[0]->B5($_[1]) }
 
-Object::Simple->build_class;
+Object::Simple::Old->build_class;
 
